@@ -389,14 +389,17 @@ impl<'client, T: Config, E: Decode + HasModuleError, Evs: Decode>
             let ev = ev?;
             if &ev.pallet == "System" && &ev.variant == "ExtrinsicFailed" {
                 let dispatch_error = E::decode(&mut &*ev.data)?;
-                if let Some((pallet_idx, error_idx)) =
-                    dispatch_error.module_error_indices()
-                {
-                    let details = self.client.metadata().error(pallet_idx, error_idx)?;
+                if let Some(error_data) = dispatch_error.module_error_data() {
+                    // Error index is utilized as the first byte from the error array.
+                    let details = self
+                        .client
+                        .metadata()
+                        .error(error_data.pallet_index, error_data.error_index())?;
                     return Err(Error::Module(ModuleError {
                         pallet: details.pallet().to_string(),
                         error: details.error().to_string(),
                         description: details.description().to_vec(),
+                        error_data,
                     }))
                 } else {
                     return Err(Error::Runtime(RuntimeError(dispatch_error)))
