@@ -20,7 +20,11 @@ mod utils;
 #[cfg(test)]
 mod client;
 #[cfg(test)]
+mod events;
+#[cfg(test)]
 mod frame;
+#[cfg(test)]
+mod storage;
 
-pub use test_runtime::node_runtime;
-pub use utils::*;
+use test_runtime::node_runtime;
+use utils::*;
